@@ -33,6 +33,7 @@ class Context(zmq.Context):
     _instance = None
 
     def __init__(self):
+        super(zmq.Context, self).__init__()
         self._middlewares = []
         self._hooks = {
             'resolve_endpoint': [],
@@ -47,6 +48,50 @@ class Context(zmq.Context):
         }
         self._reset_msgid()
 
+    # NOTE: pyzmq 13.0.0 messed up with setattr (they turned it into a
+    # non-op) and you can't assign attributes normally anymore, hence the
+    # tricks with self.__dict__ here
+
+    @property
+    def _middlewares(self):
+        return self.__dict__['_middlewares']
+
+    @_middlewares.setter
+    def _middlewares(self, value):
+        self.__dict__['_middlewares'] = value
+
+    @property
+    def _hooks(self):
+        return self.__dict__['_hooks']
+
+    @_hooks.setter
+    def _hooks(self, value):
+        self.__dict__['_hooks'] = value
+
+    @property
+    def _msg_id_base(self):
+        return self.__dict__['_msg_id_base']
+
+    @_msg_id_base.setter
+    def _msg_id_base(self, value):
+        self.__dict__['_msg_id_base'] = value
+
+    @property
+    def _msg_id_counter(self):
+        return self.__dict__['_msg_id_counter']
+
+    @_msg_id_counter.setter
+    def _msg_id_counter(self, value):
+        self.__dict__['_msg_id_counter'] = value
+
+    @property
+    def _msg_id_counter_stop(self):
+        return self.__dict__['_msg_id_counter_stop']
+
+    @_msg_id_counter_stop.setter
+    def _msg_id_counter_stop(self, value):
+        self.__dict__['_msg_id_counter_stop'] = value
+
     @staticmethod
     def get_instance():
         if Context._instance is None:
