@@ -34,6 +34,9 @@ import gevent.event
 import gevent.core
 import sys
 import errno
+from logging import getLogger
+
+logger = getLogger(__name__)
 
 class Context(_zmq.Context):
 
@@ -93,6 +96,14 @@ class Socket(_zmq.Socket):
                 self._state_event.cancel()
         super(Socket, self).close()
 
+    def connect(self, *args, **kwargs):
+        while True:
+            try:
+                return super(Socket, self).connect(*args, **kwargs)
+            except _zmq.ZMQError, e:
+                if e.errno not in (_zmq.EAGAIN, errno.EINTR):
+                    raise
+
     def send(self, data, flags=0, copy=True, track=False):
         if flags & _zmq.NOBLOCK:
             return super(Socket, self).send(data, flags, copy, track)
@@ -124,10 +135,14 @@ class Socket(_zmq.Socket):
             # the same CPU load, you get a better throughput (roughly 18.75%).
             gevent.sleep(0)
             while not self._writable.wait(timeout=1):
-                if self.getsockopt(_zmq.EVENTS) & _zmq.POLLOUT:
-                    print>>sys.stderr, "/!\\ gevent_zeromq BUG /!\\ " \
-                        "catching up after missing event (SEND) /!\\"
-                    break
+                try:
+                    if self.getsockopt(_zmq.EVENTS) & _zmq.POLLOUT:
+                        logger.error("/!\\ gevent_zeromq BUG /!\\ " + \
+                                "catching up after missing event (SEND) /!\\")
+                        break
+                except ZMQError as e:
+                    if e.errno not in (_zmq.EAGAIN, errno.EINTR):
+                        raise
 
     def recv(self, flags=0, copy=True, track=False):
         if flags & _zmq.NOBLOCK:
@@ -160,7 +175,11 @@ class Socket(_zmq.Socket):
             # the same CPU load, you get a better throughput (roughly 18.75%).
             gevent.sleep(0)
             while not self._readable.wait(timeout=1):
-                if self.getsockopt(_zmq.EVENTS) & _zmq.POLLIN:
-                    print>>sys.stderr, "/!\\ gevent_zeromq BUG /!\\ " \
-                        "catching up after missing event (RECV) /!\\"
-                    break
+                try:
+                    if self.getsockopt(_zmq.EVENTS) & _zmq.POLLIN:
+                        logger.error("/!\\ gevent_zeromq BUG /!\\ " + \
+                                "catching up after missing event (RECV) /!\\")
+                        break
+                except ZMQError as e:
+                    if e.errno not in (_zmq.EAGAIN, errno.EINTR):
+                        raise
